** Creating indices with new baseline data

	use "$merged_data/bhc_combined.dta",clear 
	
	** Marriage index
	gen bl_index_marriage = (inlist(q206_rel, 2, 3, 4)) 
	replace bl_index_marriage=. if q206_rel==.

	replace bl_index_marriage=1 if bl_index_marriage==. & q504d_marry==5    
	replace bl_index_marriage=0 if bl_index_marriage==. & q504d_marry==4	// no girls who were missing a hh survey were married it seems
	replace bl_index_marriage=1 if hh_id==32001986 // girl living away from home (taken from generating baseline indices)

	// Socio-emotional Index
	
	** Q501a-Q502c
	
	foreach var of varlist q501a_friend_num-q502c_friend_help {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
		
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_socioemotional=x/y 
	drop q501a_friend_num_sd-y

	
	// Freedom of Movement index
	
	** Q503c1-Q503c7 //1 if allowed to go alone or accompanied // try doing this another coding way
	
	forval i = 1/7 {

	gen x_q503c_allow_go`i' = (q503c`i'_allow_go !=4) if q503c`i'_allow_go != .
	
	}
	
	// original index
	
	foreach var of varlist x_q503c_allow_go* {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_movement1=x/y 
	drop x_q503c_allow_go* norm_* x y
	

	// Empowerment Index
	
	** A504a-Q505h. 504a-504k = 3 values, 505a-505h = 2 values
	
	foreach var of varlist q505a_permi_visit q505b_permi_spend {
	gen flip_`var' = `var' == 0 if `var' != .n & `var' != .
	}
	
	foreach var of varlist q504a_socialize-q504c_sch_8gade q504d_marry-q504k_often_friend {
	gen flip_`var' = `var'
	recode flip_`var' (3 = 1) (1 = 3)
	}
	
	
	foreach var of varlist  flip_* q505c_cloth_self q505d_talk_sch q505e_talk_marry-q505h_talk_prob {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_empowerment=x/y 
	drop flip_q505a_permi_visit-y
	
		
	// Self-esteem Index
	
	** Q507a-Q507d (don't know = missing), Q508c-Q508g (3 values) and Q516a-Q516b
	
	label define q507_dum 0 "No or Don't Know" 1 "Yes"
	
	** Need to write out vars so that we don't get consumption variable 507
	foreach var of varlist q507a q507b q507c q507d {

	recode `var' (2 = 0) (3 = 0)   // "Don't know" is equivalent in meaning to "No"
	label values `var' dum

	}
	
	// I'm actually making 508c-g into Yes/No, recoding "Have not thought about this" as "No"
	
	foreach var of varlist q508c_not_under_mind-q508g_work_hard {
	gen flip_`var' = `var' if `var' !=. & mis_bl_ch_survey != 1
	recode flip_`var' (2=0) (3=0)
	}
	
	gen flip_q516b_force_atten = (q516b_force_atten == 0) if q516b_force_atten != . & mis_bl_ch_survey != 1
	
	foreach var of varlist flip_* q507a q507b q507c q507d q516a {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_selfesteem=x/y 
	drop flip_q508c_not_under_mind-y
	
	// Future Planning Index
	
	**Future plans: Q508a-Q508b, Q511a, Q512c, Q512e-Q512f. For Q511a and Q512c, indicator variables
	** will be created based on whether any goal is provided (i.e. responses #1-#6 given). For
	** Q512e-Q512f, responses will take on one of five values, with the highest value corresponding to “Very true"
	
	** Making 508a/b into dummies, as "haven't thought about" seems like "no" to me
	
	gen indi_q511a = (q511a_goal != 7) if q511a_goal != .
	gen indi_q512c = (q512c_goal != 7) if q512c_goal != .
	// missing a lot of 512c because girls didn't understand the concept of goals
	
	foreach var of varlist q508a_plan_study q508b_hope_futu {
	gen flip_`var' = `var'
	recode flip_`var' (2=0) (3=0)
	}
	
	gen indi_q512e_excited = q512e_excited
	recode indi_q512e_excited (5=1) 
	
	gen indi_q512f_way_goal = q512f_way_goal
	
	foreach var of varlist flip_* indi_*{

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_planning=x/y 
	drop indi_q511a-y
	
	
	// Marital expectations index
	
	** Q513c-Q513f along with the difference between Q513a and Q513b. “Never”
	** responses to Q513a will be coded as missing. For girls already married, the index will be
	** set equal to the lowest value calculated for a non-married respondent.

	gen indi_marrdiff = q513a_age_marry_age - q513b_class_marry
	
	foreach var of varlist indi_marrdiff q513c_age q513f_wish_marry {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_marr_expect=x/y 
	drop indi_marrdiff-y
	
	egen min_marr_expect = min(bl_index_marr_expect)
	replace bl_index_marr_expect = min_marr_expect if q513a_age_marry == 2 // 2 is "already married"--checked
	drop min_marr_expect
	
	** note that this index won't have a mean of 0 because of the married girls ^^
	
	// Employment expectations index
	
	** "Q514a, Q514c-Q514d. “Other” responses to Q514c, Q514d will be coded
	** based on the closest corresponding numerical response value." // probably just makes sense to make missing
		
	** Grouping into no further / less than secondary, at least some secondary/vocational, and university
	
	** There are some answers here that don't fall into schooling categories
	** "Unclear information" - 0
	** "No interested" - 9
		** 9 was vocational in the endline survey
	** "Parents wish" - 10
	** "Parents reluctant" - 11
	** "Depends on school availability" - 12
	 
	recode q514c_amt_edu (0=.) (9=.) (10=.) (11=.) (12=.)
	recode q514d_high_edu (0=.) (9=.) (10=.) (11=.) (12=.)
	
	gen indi_leastedu = .
	replace indi_leastedu = 1 if q514c_amt_edu <=3
	replace indi_leastedu = 2 if inlist(q514c_amt_edu, 4, 5)
	replace indi_leastedu = 3 if inlist(q514c_amt_edu, 6, 7, 8)
	
	gen indi_mostedu = .
	replace indi_mostedu = 1 if q514d_high_edu <=3
	replace indi_mostedu = 2 if inlist(q514d_high_edu, 4, 5, 9)
	replace indi_mostedu = 3 if inlist(q514d_high_edu, 6, 7, 8)
	
	foreach var of varlist indi_* q514a_job_future {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_employ=x/y 
	drop indi_leastedu-y

	
	// Gender norms index
	
	** Q515a-Q515f
	
	foreach var of varlist q515a_marry_edu q515b_necess_dowry q515c_boys_sent q515f_better_boys {	
	gen flip_`var' = (`var' == 0) if `var' != . & `var' != .n
	}
	
	foreach var of varlist q515d_same_chore q515e_same_freedom{	
	gen indi_`var' = `var' if `var' != . & `var' != .n
	}
	
	foreach var of varlist flip_* indi_*  {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_gender=x/y 
	drop flip_q515a_marry_edu-y
	
	
	// Cantrill ladder
	
	** 1-10
	
	gen bl_index_cantrill = q517_cantrill_ladder
	
	// Enumerator assessment index
	
	** Index from 702-705
	
	foreach var of varlist q702_atten_instruc q703_careful q704_alert q705_confident {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_enumerator=x/y 
	drop q702_atten_instruc_sd-y
	
	global table6_2_vars bl_index_marriage bl_index_socioemotional bl_index_movement1 bl_index_empowerment bl_index_selfesteem bl_index_planning bl_index_marr_expect bl_index_employ bl_index_gender bl_index_cantrill bl_index_enumerator
	

*********** Life skills, objective measures (Table 6-1)

	
	** Delay discounting
	gen bl_index_delay = q510a_prefer
 
	** Shouldn't be an index
	
	** Completed mirror drawings
	// "completed" versus "attempted"??
	// there are times for people that did not attempt it?

	gen indi_attempt_a = q439_track_task_a if q439_track_task_a != .
	gen indi_attempt_b = q439_track_task_b if q439_track_task_b != .
	gen indi_attempt_c = q439_track_task_c if q439_track_task_c != .
	gen indi_attempt_d = q439_track_task_d if q439_track_task_d != .
	
	gen indi_attempts = indi_attempt_a + indi_attempt_b + indi_attempt_c + indi_attempt_d
	
	replace indi_attempts = 0 if indi_attempts == . & mis_bl_ch_survey != 1 // replacing with 0 unless the survey is missing totally
	
	gen time_a = 60*q439_track_task_a_min + q439_track_task_a_sec if indi_attempt_a == 1
	replace time_a = 0 if indi_attempt_a == 0
	gen time_b = 60*q439_track_task_b_min + q439_track_task_b_sec if indi_attempt_b == 1
	replace time_b = 0 if indi_attempt_b == 0
	gen time_c = 60*q439_track_task_c_min + q439_track_task_c_sec if indi_attempt_c == 1
	replace time_c = 0 if indi_attempt_c == 0
	gen time_d = 60*q439_track_task_d_min + q439_track_task_d_sec if indi_attempt_d == 1
	replace time_d = 0 if indi_attempt_d == 0
	
	gen all_time = time_a + time_b + time_c + time_d
	
	rename indi_attempts bl_index_attempts
	rename all_time bl_index_time
	
	drop indi_attempt* time_*

	
	** Scavenger hunt index
	** Create indices from completed and attempted, then create an index from those
	
	destring q517b_outcome*, replace
	
	forval i = 1/10 {
	gen found_`i' = q517b_outcome`i' == 1 if q517b_outcome`i' != .
	gen attempt_`i' = q517b_outcome`i' != 3 if q517b_outcome`i' != .
	}
	
	gen indi_found = found_1 + found_2 + found_3 + found_4 + found_5 + found_6 + found_7 + found_8 + found_9 + attempt_10
	gen indi_attempt = attempt_1 + attempt_2 + attempt_3 + attempt_4 + attempt_5 + attempt_6 + attempt_7 + attempt_8 + attempt_9 + attempt_10
	
	foreach var of varlist indi_found indi_attempt {
	egen `var'_sd=sd(`var') if treat==0
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean= mean(`var') if treat==0
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_scavenger=x/y
	drop  found_1 - y
	
	
	global table6_1_vars bl_index_delay bl_index_attempts bl_index_time bl_index_scavenger
	
	************ Child labor ***********
	** Copied from generating_baseline_indices_final
	** Added in kinds of labor that were designated as work in the endline
	**General EE Recode

*adjust for skip patterns
replace q302_help_farm=0 if q302_help_farm==. & q301_own_farm==0
replace q303_paid=0 if q303_paid==. & q302_help_farm==0
replace q305_spend_busi=0 if q305_spend_busi==. & q304_own_busi==0
replace q306_income=0 if q306_income==. & q305_spend_busi==0
replace q308_paid=0 if q308_paid==. & q307_work_not_fly==0


*Children working outside of family based work in the last 12 months 
	gen work_nonfamily= (q332_work_not_fly==1 | q307_work_not_fly==1 | q418_work_site == 1)
	replace work_nonfamily=. if (q332_work_not_fly==. & q307_work_not_fly==. & q418_work_site ==.)
	replace work_nonfamily=. if work_nonfamily==0 & (q332_work_not_fly==. | q307_work_not_fly==. | q418_work_site ==.)
	label var work_nonfamily "Work involved with non-family members"
	
*construct hours economic activity;
	destring q311_cal_duration*, replace
	gen hours_worked=0
	forval i= 1/32 {
			replace hours_worked= hours_worked+ q311_cal_duration`i' if (q311_activity`i'>=17) & (q311_activity`i' <=65)	
	}
	forval i = 1/32 {
			replace hours_worked= hours_worked+ q311_cal_duration`i' if inlist(q311_activity`i', 7, 8, 73, 77, 78, 81, 85, 88, 92, 94, 95, 96, 97)
	}
	*EE Expanded activity codes
	replace hours_worked=hours_worked/60
	replace hours_worked=. if q311_activity1==.
	label var hours_worked "Hours worked in typical day in last week"
	
*construct hours unpaid household services
	gen hours_unpd_hhser=0
	** Adding in the ones after 2, 3, 4
	forval i= 1/32 {
			replace hours_unpd_hhser= hours_unpd_hhser+ q311_cal_duration`i' if inlist(q311_activity`i', 2, 3, 4, 6, 66, 68, 71, 76, 82, 91, 93)
	}
	replace hours_unpd_hhser=hours_unpd_hhser/60
	label var hours_unpd_hhser "Hours in unpaid households services in a typical day in last week"
	
	***EE Expand Activity Codes
	replace hours_unpd_hhser=. if q311_activity1==.

*Hours based inputs into later aggregates
*5 hours per day corresponding to 20/wk
*Children economically active for 20 or more hours in the last week
g ea_gt20= hours_worked>=5
replace ea_gt20=. if hours_worked==.
label var ea_gt20 "Hours worked greater than 5 hours in a typical day in last week"

*Children participating in unpaid household services for 20 or more hours in the last week
g uhs_gt20= hours_unpd_hhser>=5
replace uhs_gt20=. if hours_unpd_hhser==.
label var uhs_gt20 "Hours in unpaid household services greater than 5 hours in a typical day in last week"

*these are outcome variables used later
	*total hours active
	gen hours_active =hours_worked + hours_unpd_hhser
	label var hours_active "Total Hours Active in Work and Unpaid Household Services"

	**Hours active outside home
	gen hours_outside=0
	*some activities are ambigious as to if they are outside of home
	*we define them as outside the home if the respondent says they did some things outside the home
		*it is not perfect
	forval i= 1/32 {
			replace hours_outside= hours_outside+ (q311_cal_duration`i'*work_nonfamily) if (q311_activity`i'>=18) & (q311_activity`i' <=24)	
			replace hours_outside= hours_outside+ (q311_cal_duration`i'*work_nonfamily) if (inlist(q311_activity`i', 73, 92, 94, 97))

	}
	*these activities are more commonly outside of home
	forval i= 1/32 {
			replace hours_outside= hours_outside+ (q311_cal_duration`i') if (q311_activity`i'>=25) & (q311_activity`i' <=59)	
	}
	
	forval i= 1/32 {
			replace hours_outside= hours_outside+ q311_cal_duration`i' if (inlist(q311_activity`i', 7, 8, 17, 61, 62, 63, 64, 65, 88, 95, 96))
	}

	replace hours_outside=hours_outside/60
	***BF change
	replace hours_outside=. if q311_activity1==.

*Children in an occupation listed in Appendix One
*Children participating in any of the processes listed in Appendix Two

g probact_d=0

	forval i= 1/32 {
			replace probact_d= 1 if inlist(q311_activity`i', 25, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 57, 58, 61, 62, 63, 65)
			}
	replace probact_d=. if q311_activity1==.
	label var probact_d "Child participated in a prohibited occupation or process in a typical day in last week"
	
g probact_7= inlist(q310_type_work, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 30, 41, 42, 45, 46, 47, 49)
	replace probact_7=. if q307_work_not_fly==. & q302_help_farm==. & q305_spend_busi==.
	replace probact_7=0 if q307_work_not_fly==0 & q302_help_farm==0 & q305_spend_busi==0 & probact_7~=1
	label var probact_7 "Child participated in a prohibited occuption or process in the last 7 days"
	
	g probact= probact_7==1 | probact_d==1
	replace probact=. if probact_7==. & probact_d==.
	replace probact=. if probact==0 &  (probact_7==. | probact_d==.)
		label var probact "Child pariticpated in prohibited occupation or process in last 7 days or in typical day"
	

	
*Children working in an economic activity in the last 12 months that is hazardous by its nature or circumstance (based on self-reported job characteristics). 
g hazcirc=0

	#delimit;

	foreach x in 
	q401_work_sun q402_prob_light q403_noises q404_extr_temp q405_brick_indust q406_crushing q407_polishing 
	q408_construction q409_loads q410_machinery q411_injured q412_toxic q414_unwell q415_hazardous {;
		replace hazcirc= 1 if `x'==1; 
	};
	
	foreach x in 
	q415_hazardous {;
		replace hazcirc= . if `x'==. & hazcirc==0; 
	};

	replace hazcirc=0 if hazcirc==. & (q330_help_farm==0 & q331_spend_busi==0 & q332_work_not_fly==0 );

	label var hazcirc "Working under self-reported hazardous circumstances";
	
	#delimit cr

label var hazcirc "Child participated in hazardous work in last 12 months based on circumstances of work"

*Child (potentially) in forced labor (reports being forced to work and unable to leave)
g pfl=0

replace pfl= 1 if  (q419_able_leave==0 | q420_able_refuse==0 | q421_able_leave==0 |  inlist(q416_whether, 3, 4, 5, 6,7))
foreach x in q419_able_leave q420_able_refuse q421_able_leave  {
replace pfl=. if pfl==0 & `x'==.
}

replace pfl=0 if pfl==.  & (q330_help_farm==0 & q331_spend_busi==0 & q332_work_not_fly==0 )
label var pfl "Potentially in forced labor, unable to refuse work"


*Children (potentially) in debt bondage (reports working for a debt and being unable to leave)
replace q422_off_debt=0 if q422_off_debt==. & q421_able_leave==1
replace q422_off_debt=1 if q416_whether==5

g pdb=pfl * q422_off_debt
replace pdb=0 if pdb==. & (q330_help_farm==0 & q331_spend_busi==0 & q332_work_not_fly==0 )

label var pdb "Potentially in Debt-Bondage, unable to refuse work and working off debt"

replace pfl=0 if q330_help_farm==0 & q331_spend_busi==0 & q332_work_not_fly==0  
replace pdb=0 if q330_help_farm==0 & q331_spend_busi==0 & q332_work_not_fly==0 

*Aggregates
*Children Engaged in Other Worst Forms of Child Labor
gen otherworst_labor= pfl==1 | pdb==1
replace otherworst_labor=. if pfl==. & pdb==.
replace otherworst_labor=. if (pfl==. | pdb==.) & otherworst_labor==0
label var otherworst_labor "Engaged in Other Worst Forms of Child Labor"

*Children Engaged in Hazardous Child Labor
g hazardous_labor = hazcirc==1 | probact==1
replace hazardous_labor=. if hazcirc==. & probact==.
replace hazardous_labor=. if hazardous_labor==0 & (hazcirc==. | probact==.)
label var hazardous_labor "Engaged in Hazardous Child Labor"

*Child labor
g child_labor = hazardous_labor==1 | otherworst_labor==1 | ea_gt20==1 | uhs_gt20==1 | work_nonfamily==1
replace child_labor =. if hazardous_labor==. & otherworst_labor==. & ea_gt20==. & uhs_gt20==. & work_nonfamily==.
replace child_labor =. if child_labor==0 & (hazardous_labor==. | otherworst_labor==. | ea_gt20==. | uhs_gt20==. | work_nonfamily==.)
label var child_labor "Engaged in Child Labor"

*Working Child
gen work_child=(q330_help_farm==1|q331_spend_busi==1| q332_work_not_fly==1 | q302_help_farm==1 | q305_spend_busi ==1 | q307_work_not_fly == 1 | child_labor==1)
replace work_child=. if (q330_help_farm==. & q331_spend_busi==. & q332_work_not_fly==. & q302_help_farm ==. & q305_spend_busi == . & q307_work_not_fly == . & child_labor==.)
replace work_child=. if work_child==0 & (q330_help_farm==. | q331_spend_busi==. | q332_work_not_fly==. | q302_help_farm ==. | q305_spend_busi == . | q307_work_not_fly == . | child_labor==.)
label var work_child "Child is Economically Active or in Child Labor"


**Working for pay
gen work_pay=	(q430_receiv_cash==1 | q431_receiv_skill==1 | q432_receiv_edu==1 | q433_receiv_shelt==1 | q434_receiv_medi==1 | q436_receiv_oth==1 | q303_paid==1 | q306_income==1 | q308_paid==1)
	replace work_pay=. if work_child==.
	label var work_pay "Works for Pay"

	
foreach x in work_child work_pay work_nonfamily hours_worked hours_unpd_hhser hours_active hours_outside hazardous_labor otherworst_labor child_labor ea_gt20 uhs_gt20 probact hazcirc pdb pfl {
summ `x'
ren `x' bl_`x'
}

	global table7_vars bl_work_child bl_work_pay bl_work_nonfamily bl_child_labor bl_hazardous_labor bl_otherworst_labor bl_hours_worked bl_hours_unpd_hhser bl_hours_active bl_hrs_act_out_house
	

	****** School outcomes *******

	***Generating Cognitive variables
	**Time spent studying outside school
	gen hours_out_sch=0
	forval i= 1/32 {
			replace hours_out_sch= hours_out_sch+ q311_cal_duration`i' if (q311_activity`i'==14|q311_activity`i'==15)	
	}
	replace hours_out_sch=hours_out_sch/60
	***BF change
	replace hours_out_sch=. if q311_activity1==.
	rename hours_out_sch bl_time_homework
	

	**Time spent on school
	gen hours_sch=0
	forval i= 1/32 {
			replace hours_sch= hours_sch+ q311_cal_duration`i' if (q311_activity`i'==9|q311_activity`i'==10 | q311_activity`i'==14|q311_activity`i'==15)	
	}

	replace hours_sch=hours_sch/60
	***BF change
	replace hours_sch=. if q311_activity1==.
	rename hours_sch bl_time_school

	global table8_vars bl_time_homework bl_time_school
	
	***** Creating indices 
	
	//keep child_id hh_id dise strata* mirror_* $table6_1_vars $table6_2_vars $table7_vars $table8_vars 
	
	tempfile var_set_1
	save `var_set_1'
	
	****************************************************************************
	*********** Parent perception indices
	
	global q416_negative q416b q416c q416e q416f q416h q416j q416l q416n q416o q416s q416t 
	global q416_positive q416a q416d q416g q416i q416k q416m q416p q416q q416r q416u
	
	** Putting f: "Would rather be alone than with other youth" as negative
	** Putting s: "Gets aong better with adults than with other youth" as negative (but unclear)
	
	foreach var of varlist $q416_negative {
	gen flip_`var' = (`var' == 1) if `var' != .
	recode flip_`var' (3=1) (1=3)
	}
	
	foreach var of varlist flip_* $q416_positive {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_strengths=x/y 
	drop flip_q416b_restless-y
	
	// parental perception of girl's self-efficacy
	** Index from 417a-417e
		
	cap drop q417_desc_site	q417_desc_site_oth
		
	foreach var of varlist q417* {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_efficacy=x/y 
	drop q417a_oppose_sd-y
	// a few observations are missing because 'Don't know' are coded as missing, as instructed
	
	
	// parental pareception of freedom of movement
	** 418a-h (1 = allowed to go alone or accompanied, 0 = otherwise)
	** like above, will recode as a second version too, where 0 = accopanied only / not allowed to go
	
	foreach var of varlist q418a_school - q418f_market q418h_vlg {
	
	gen x_`var' = (`var' !=4) if `var' != .n & `var' !=.
	
	}
	
	// original index
	
	foreach var of varlist x_q418* {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_movement1=x/y 
	drop x_q418* norm_* x y

	
	// parent-daughter communication
	** 419a-420h; 419 = 2 values, 420 = 3 values
	
	foreach var of varlist q419* q420*{

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_communication=x/y 
	drop q419a_worry_sd- y
	
	// Parental gender attitudes
	** 424a-i
	
	foreach var of varlist q424b_obey q424c_edu q424d_dowry q424e_school q424h_study {
	gen flip_`var' = `var' + 1
	replace flip_`var' = 0 if flip_`var' == 2   // flipping direction--okay
	}
	
	foreach var of varlist flip_* q424a_work_outside q424f_hh_work q424g_frredom q424i_leader {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_gender=x/y 
	drop flip_q424b_obey - y
	
	
	// parental schooling attitudes
	** 425-427; 440b. "Don't know" for 440b = missing
	** 440b is actually 439b in endline
	
	gen indi_low_lev = .
	replace indi_low_lev = 1 if inlist(q425_low_grade, 1, 2, 3)
	replace indi_low_lev = 2 if inlist(q425_low_grade, 4, 5)
	replace indi_low_lev = 3 if inlist(q425_low_grade, 6, 7, 8) // 8 is "as much as she wants"
	
	gen indi_highest = .
	replace indi_highest = 1 if inlist(q426_high_grade, 1, 2, 3)
	replace indi_highest = 2 if inlist(q426_high_grade, 4, 5)
	replace indi_highest = 3 if inlist(q426_high_grade, 6, 7, 8) // 8 is "as much as she wants"
	
	gen flip_q428_end_school = (q428_end_school == 0) if q428_end_school != . // corrected to be the right dummy reference
	
	foreach var of varlist indi_* flip_q428_end_school q440b_edu {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_schooling=x/y 
	drop indi_low_lev - y
	
	
	// parental marriage attitudes
	** difference between 434 and 4432; difference between 435 and 432; 437; 440d-f
	** Don't know / don't expect her to do this = missing
	
	gen dif1 = q434_ideal_age - q432_age_marriage
	gen dif2 = q435_high_age - q432_age_marriage
	
	foreach var of varlist q440d_marriage-q440f_leave_hh{
		recode `var' (5=.) // don't expect her to do this = missing; don't know is missing
	}
		
		foreach var of varlist dif* q437_after18 q440d_marriage-q440f_leave_hh{
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen bl_index_p_marriage =x/y 
	drop dif1 - y
	
	global table6_3_vars bl_index_p_*
	

	*Locus of control, rosenberg, perceived stress all only at endline
	
	** Table 5: school progression & completion
	
	** Dropout
	** 1 if HH Q214 is "no" or if child survey Q203 is "no" 
	
	gen dropout=1 if (q214_school==0 | q203_atten_sch==0)
	replace dropout=0 if dropout==. & (q214_school!=. | q203_atten_sch!=.)
	
	** Grade progression: 
	** Baseline equivalent is at or above grade 5

	g gr_prog= q204_class>=5 
	replace gr_prog=. if q204_class==.
	replace gr_prog=0 if gr_prog==. & q203_atten_sc==0
	replace gr_prog=0 if dropout==1

	gen attend= q205_go_sch_days/q206_open_sch_days
	replace attend = . if dropout==1

	gen dum_attend= attend>0
	replace dum_attend=. if attend==.

	foreach var of varlist gr_prog attend dum_attend {
	replace `var' =. if mis_bl_ch_survey == 1
	}

	rename dropout bl_index_dropout
	rename gr_prog bl_index_grade
	rename attend bl_school_attend
	rename dum_attend bl_school_dummy
		
	** Age for balance table
	gen  girl_age = q203_age

	**********************
	
	
	global table5_vars bl_index_dropout bl_index_grade bl_school_attend bl_school_dummy
		
	destring q517b_*, replace
	
	********** Controls & variables for heterogeneous treatment ***************
	** Note mother's education is created in endline indexes file

	gen bl_economicshock = q113a==1 | q113b==1 | q113c==1 if mis_bl_hh_survey != 1 & new_el != 1     
	gen bl_deathillshock = q113d==1 | q113e==1 | q113f==1  if mis_bl_hh_survey != 1 & new_el != 1 	
	gen bl_crimedisputeshock = q113h==1 | q113i==1 | q113j==1 if mis_bl_hh_survey != 1 & new_el != 1  
	
	gen bl_q203_age = q203_age
	
	replace q104_employment=. if q104_employment==99 | q104_employment == -96 // added in the -96 coding
	
	tabulate q104_employment, gen (employ) 
	tabulate q203_age, gen (age) 


	keep bl_* dise treat child_id hh_id mis_* new_el age* employ* abvmed_qualindex q103_social_grp
	
	drop if child_id == .

	** nonmis data is used for balance tables	
	save "$merged_data/bl_indices_nonmis.dta",replace // version that doesn't replace missing with 0 in indices

	** for imbalance controls
	gen bl_obc = (q103_social_grp == 3) if mis_bl_hh_survey != 1 & new_el != 1  
		
	foreach var of varlist bl_* employ1-employ6 age* {
	gen mis_`var' = (`var'==.)
	replace `var'=0 if `var'==.
	}

	drop q103_social_grp	
		
	save "$merged_data/bl_indices.dta",replace
	
	
	
	
