** Merging baseline section data sets

clear all
set more off
pause off

	**** Child survey merge ****

	use "$data/bcsection0.dta",clear
	merge 1:1 child_id using "$data/bcsection1.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection2.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection3.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection4.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection5.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection5_objmeasures.dta"
	drop _merge
	merge 1:1 child_id using "$data/bcsection7.dta"
	drop _merge
	
	** Calculate length of activities for Q311
	forval i = 1/32 {
	local j = `i' + 1
	gen q311_cal_duration`i' = (q311_to_time_hr`i' - q311_from_time_hr`i')*60 + q311_to_time_min`i' - q311_from_time_min`i' if q311_activity`i' != .
	label var q311_cal_duration`i' "311.`j' Minutes spent doing activity `i'"
	}
	
	save "$merged_data/bc_all.dta",replace
	
	** All merged 100%, with 2399 observations each
	
	**** Household merges ****
	
	** Merge 0, 1, 5, 6/7 (all at household level)
	
	use "$data/bhsection0.dta",clear
	merge 1:1 hh_id using "$data/bhsection1.dta"
	drop _merge
	merge 1:1 hh_id using "$data/bhsection5.dta"
	drop _merge
	merge 1:1 hh_id using "$data/bhsections67.dta"
	drop _merge
	
	tempfile bhsections01567
	save `bhsections01567'
	//save "$merged_data/bhsections01567.dta",replace

	** Merge into section 4 data, where there are multiple hh_id observations for multi-girl houses
	
	use "$data/bhsection4.dta",clear
	merge m:1 hh_id using `bhsections01567'
	drop _merge
	
	tempfile bhsections014567
	save `bhsections014567'
	
	** Use section 2 data, keep only observations for target girls 
	
	use "$data/bhsection2.dta", clear
	keep if child_id !=.
		
	** Merge with rest of household survey data 	
	merge 1:1 child_id using "`bhsections014567'"
		
	** Just the five girls we've been having issues with didn't merge	
	drop _merge
		
	save "$merged_data/bhsections0124567_child.dta", replace

	** Now merge in child survey data
	
	merge 1:1 child_id hh_id using "$merged_data/bc_all.dta"
	
	gen mis_bl_ch_survey = _merge == 1   // missing baseline child survey
	gen mis_bl_hh_survey = _merge == 2   // missing baseline household survey
	
	drop _merge
			
	** Merge in whether they're present at endline
	merge 1:1 child_id hh_id using "$merged_data/e_cid_hid_map.dta"
	
	gen mis_el = _merge == 1  // in baseline, missing at endline
	gen new_el = _merge == 2  // not in baseline, present at endline

	drop _merge
		
	save "$merged_data/bhc_combined.dta",replace

	
	
