** Endline indices
	
* Table 1: summary statistics

	use "$merged_data/ehc_combined.dta",clear
	
	** Avoiding having to specify missing type
	** Making all that are currently marked as .n or .d as .
	ds, has(type numeric)
foreach v in `r(varlist)' {
	replace `v' = . if `v'==.n
	replace `v' = . if `v'==.d

	}

	** Check that households with multiple girls show up multiple times

	duplicates tag hh_id, gen(multiple) // have the right multiples of households
	tab multiple
	drop multiple
	
	gen el_index_marriage = (inlist(a206_relation_, 2, 3, 4)) if mis_el_hh_survey != 1
	replace el_index_marriage = 1 if el_index_marriage == . & mis_el_hh_survey == 1   // the girl who is missing a child survey is married

	** Rest of the life skills indices
	
	** Recode long names
	rename q504c_contschl_pst8thgd q504c_contschl // name was too long
	rename q504k_spndtime_wthfrnds q504k_spndtime // name was too long
	rename q508f_spndext_timegetright q508f_getright // name too long
	rename q515c_boytoschl_bfrgirls q515c_boytoschl // name too long
	rename q515f_boysntrl_btrgirls q515f_boysntrl // name too long
	rename q515d_boysgirls_hhchores q515d_hhchores
	rename q515e_girlboy_smefreedm q515e_smefreedm
	
	// Socio-emotional Index
	
	** Q501a-Q502c
	
	foreach var of varlist q501a_gdfrnds-q502c_help_advce {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
		
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_socioemotional=x/y 
	drop q501a_gdfrnds_sd-y

	
	// Freedom of Movement index
	
	** Q503c1-Q503c7 //1 if allowed to go alone or accompanied
	
	forval i = 1/7 {
	
	gen x_q503c_whnvisit_place_`i' = (q503c_whnvisit_place_`i' !=4) if q503c_whnvisit_place_`i' != . & mis_el_ch_survey != 1
	gen y_q503c_whnvisit_place_`i' = (inlist(q503c_whnvisit_place_`i', 1, 3)) if q503c_whnvisit_place_`i' != . & mis_el_ch_survey != 1
	
	}
	
	// original index
	
	foreach var of varlist x_q503c_whnvisit_place_* {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_movement1=x/y 
	drop x_q503c_whnvisit_place_* norm_* x y
		
	// Empowerment Index
	
	** A504a-Q505h. 504a-504k = 3 values, 505a-505h = 2 values
	
	foreach var of varlist q505a_perm_visitfrnd q505b_perm_spnd5_15rs {
	gen flip_`var' = `var' == 0 if `var' != . & mis_el_ch_survey != 1
	}
	
	foreach var of varlist q504a_social_outhom-q504c_contschl q504d_whou_marry-q504k_spndtime {
	gen flip_`var' = `var' if mis_el_ch_survey != 1
	recode flip_`var' (3 = 1) (1 = 3)
	}
	
	
	foreach var of varlist  flip_* q505c_ichse_clthswear-q505h_talkprnts_prbwthfrnds {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_empowerment=x/y 
	drop flip_q505a_perm_visitfrnd-y
	
		
	// Self-esteem Index
	
	** Q507a-Q507d (don't know = missing), Q508c-Q508g and Q516a-Q516b
	
	// Making 508c-g into Yes/No, recoding "Have not thought about this" as "No"
	
	foreach var of varlist q508c_finddiffway-q508g_succbcz_wrkhard {
	gen flip_`var' = `var' if mis_el_ch_survey != 1
	recode flip_`var' (2=0) (3=0)
	}
	
	gen flip_q516b_dullcls_payattn = (q516b_dullcls_payattn == 0) if q516b_dullcls_payattn != . & mis_el_ch_survey != 1
	
	foreach var of varlist flip_* q507* q516a {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_selfesteem=x/y 
	drop flip_q508c_finddiffway-y
	
	// Future Planning Index
	
	**Future plans: Q508a-Q508b, Q511a, Q512c, Q512e-Q512f. For Q511a and Q512c, indicator variables
	** will be created based on whether any goal is provided (i.e. responses #1-#6 given). For
	** Q512e-Q512f, responses will take on one of five values, with the highest value corresponding to “Very true"
	
	** Making 508a/b into dummies, as "haven't thought about" is the same sentiment as "no"
	
	gen indi_q511a = (q511a_goal != 6) if q511a_goal != . & mis_el_ch_survey != 1
	gen indi_q512c = (q512c_what != 7) if q512c_what != . & q512c_what != . &  mis_el_ch_survey != 1
	
	foreach var of varlist q508a_mkplans_future q508b_hopefuture {
	gen flip_`var' = `var' if mis_el_ch_survey != 1
	recode flip_`var' (2=0) (3=0)
	}
	
	gen indi_q512e_exctd_rchnggoal = q512e_exctd_rchnggoal
	recode indi_q512e_exctd_rchnggoal (5=1)
	
	gen indi_q512f_sticktoplan = q512f_sticktoplan
	
	foreach var of varlist flip_* indi_*{

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_planning=x/y 
	drop indi_q511a-y
	
	
	// Marital expectations index
	
	** Q513c-Q513f along with the difference between Q513a and Q513b. “Never”
	** responses to Q513a will be coded as missing. For girls already married, the index will be
	** set equal to the lowest value calculated for a non-married respondent.
	
	gen indi_marrdiff = q513a_age_marriage - q513b_agr_girlgetmarrd if mis_el_ch_survey != 1
	
	foreach var of varlist indi_marrdiff q513c_erlstage_mrrge-q513f_parntscnsdr_marrg {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_marr_expect=x/y 
	drop indi_marrdiff-y
	
	egen min_marr_expect = min(el_index_marr_expect)
	replace el_index_marr_expect = min_marr_expect if q504_areu_currmarrd == 1 // set equal to minimum
	drop min_marr_expect
	
	// Employment expectations index
	
	** Q514a, Q514c-Q514d. “Other” responses to Q514c, Q514d will be coded
	** based on the closest corresponding numerical response value. // probably just makes sense to make missing
	
	** Grouping into no further / less than secondary, at least some secondary/vocational, and university
	
	gen indi_leastedu = .
	replace indi_leastedu = 1 if q514c_leadtedu <=3 & mis_el_ch_survey != 1
	replace indi_leastedu = 2 if inlist(q514c_leadtedu, 4, 5, 9) & mis_el_ch_survey != 1
	replace indi_leastedu = 3 if inlist(q514c_leadtedu, 6, 7, 8) & mis_el_ch_survey != 1
	
	gen indi_mostedu = .
	replace indi_mostedu = 1 if q514d_highedu_finish <=3 & mis_el_ch_survey != 1
	replace indi_mostedu = 2 if inlist(q514d_highedu_finish, 4, 5, 9) & mis_el_ch_survey != 1
	replace indi_mostedu = 3 if inlist(q514d_highedu_finish, 6, 7, 8) & mis_el_ch_survey != 1
	
	foreach var of varlist indi_* q514a_jobpay_futre {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_employ=x/y 
	drop indi_leastedu-y

	
	// Gender norms index
	
	** Q515a-Q515f
	
	foreach var of varlist q515a_girlsnt_highedu q515b_givedowry q515c_boytoschl q515f_boysntrl {	
	gen flip_`var' = (`var' == 0) if `var' != . & `var' != . & mis_el_ch_survey != 1
	}
	
	foreach var of varlist q515d_hhchores q515e_smefreedm {	
	gen indi_`var' = (`var' == 1) if `var' != . & `var' != . & mis_el_ch_survey != 1
	}
	
	foreach var of varlist flip_* indi_*  {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_gender=x/y 
	drop flip_q515a_girlsnt_highedu-y
	
	
	// Cantrill ladder
	
	** 1-10
	
	gen el_index_cantrill = q517_stnd_atprsnt 
	
	// Enumerator assessment index
	
	** Index from 702-705
	
	foreach var of varlist q702-q705 {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_enumerator=x/y 
	drop q702_patattn_instrutns_sd-y
	
	************************ Parent indices ************************
	
	// parental perception of girl's strengths
	** Index from 416a-416u
	global a416_negative a416b a416c a416e a416f a416h a416j a416l a416n a416o a416s a416t 
	global a416_positive a416a a416d a416g a416i a416k_good_frnd_ a416m a416p a416q a416r a416u
	
	** Putting f: "Would rather be alone than with other youth" as negative
	** Putting s: "Gets aong better with adults than with other youth" as negative
	
	foreach var of varlist $a416_negative {
	gen flip_`var' = (`var' == 1) if `var' != .
	recode flip_`var' (3=1) (1=3)
	}
	
	foreach var of varlist flip_* $a416_positive {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_strengths=x/y 
	drop flip_a416b_restless_-y
	
	// parental perception of girl's self-efficacy
	** Index from 417a-417e
	
	foreach var of varlist a417* {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_efficacy=x/y 
	drop a417a_point_view__sd-y
	// a few observations are missing because 'Don't know' are coded as missing, as instructed
	
	
	// parental pareception of freedom of movement
	** 418a-h (1 = allowed to go alone or accompanied, 0 = otherwise)
	
	foreach var of varlist a418a_school_ - a418h_village_ {
	
	gen x_`var' = (`var' !=4) if `var' != .
	gen y_`var' = (inlist(`var', 1, 3)) if `var' != .
	
	}
	
	// original index
	
	foreach var of varlist x_a418* {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_movement1=x/y 
	drop x_a418* norm_* x y
	

	
	// parent-daughter communication
	** 419a-420h; 419 = 2 values, 420 = 3 values

	foreach var of varlist a419* a420*{

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_communication=x/y 
	drop a419a_worries__sd- y
	
	// Parental gender attitudes
	** 424a-i
	
	foreach var of varlist a424b_husband_ a424c_high_educ_ a424d_dowry_ a424e_money_scarce_ a424h_studying_ {
	gen flip_`var' = `var' + 1
	replace flip_`var' = 0 if flip_`var' == 2
	}
	
	foreach var of varlist flip_* a424a_wrk_out_hme_ a424f_same_amt_chore_ a424g_freedom_boy_ a424i_leaders_ {

		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_gender=x/y 
	drop flip_a424b_husband_ - y
	
	
	// parental schooling attitudes
	** 425-427; 440b. "Don't know" for 440b = missing
	** 440b is actually 439b in endline
	
	gen indi_low_lev = .
	replace indi_low_lev = 1 if inlist(a425_low_lev_schl_, 1, 2, 3)
	replace indi_low_lev = 2 if inlist(a425_low_lev_schl_, 4, 5)
	replace indi_low_lev = 3 if inlist(a425_low_lev_schl_, 6, 7)
	
	gen indi_highest = .
	replace indi_highest = 1 if inlist(a426_highest_, 1, 2, 3)
	replace indi_highest = 2 if inlist(a426_highest_, 4, 5)
	replace indi_highest = 3 if inlist(a426_highest_, 6, 7)
	
	gen flip_a427_point_ = (a427_point_ == 0) if a427_point_ != .
	
	foreach var of varlist indi_* flip_a427_point_ a439b_leave_ {
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_schooling=x/y 
	drop indi_low_lev - y
	
	
	// parental marriage attitudes
	** difference between 434 and 4432; difference between 435 and 432; 437; 440d-f
	** Don't know / don't expect her to do this = missing
	
	gen dif1 = a433_ideal_age_marriage_ - a431_girl_marriage_age_
	gen dif2 = a434_old_age_married_ - a431_girl_marriage_age_
	
	foreach var of varlist a439d_married_-a439f_leave_hh_ {
		recode `var' (5=.) // don't expect her to do this = missing
	}
	
		foreach var of varlist dif* a436_advant_girl_ a439d_married_-a439f_leave_hh_{
	
		egen `var'_sd=sd(`var') if treat==0 & `var'!=.
		levelsof `var'_sd, local(x)
		replace `var'_sd=`x'
		egen `var'_mean=mean(`var') if treat==0 & `var'!=.
		levelsof `var'_mean, local(x)
		replace `var'_mean=`x'
		gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_p_marriage =x/y 
	drop dif1 - y
	
	// locus of control index
	** Index based on scoring: one point for each response that is consistent w/ external locus of control
	
	replace q518_locus_control1 = "1" if q518_locus_control1 == "a"
	replace q518_locus_control2 = "1" if q518_locus_control2== "b"
	replace q518_locus_control3 ="1" if q518_locus_control3== "b"
	replace q518_locus_control4 ="1" if q518_locus_control4== "b"
	replace q518_locus_control5 ="1" if q518_locus_control5== "a"
	replace q518_locus_control6="1" if q518_locus_control6== "a"
	replace q518_locus_control7 ="1" if q518_locus_control7== "a"
	replace q518_locus_control8 ="1" if q518_locus_control8== "b"
	replace q518_locus_control9 ="1" if q518_locus_control9== "b"
	replace q518_locus_control10 ="1" if q518_locus_control10== "b"
	replace q518_locus_control11 ="1" if q518_locus_control11== "b"
	replace q518_locus_control12 ="1" if q518_locus_control12== "b"
	replace q518_locus_control13="1" if q518_locus_control13== "b"
	
	replace q518_locus_control1 = "0" if q518_locus_control1 == "b"
	replace q518_locus_control2 = "0" if q518_locus_control2== "a"
	replace q518_locus_control3 ="0" if q518_locus_control3== "a"
	replace q518_locus_control4 ="0" if q518_locus_control4== "a"
	replace q518_locus_control5 ="0" if q518_locus_control5== "b"
	replace q518_locus_control6="0" if q518_locus_control6== "b"
	replace q518_locus_control7 ="0" if q518_locus_control7== "b"
	replace q518_locus_control8 ="0" if q518_locus_control8== "a"
	replace q518_locus_control9 ="0" if q518_locus_control9== "a"
	replace q518_locus_control10 ="0" if q518_locus_control10== "a"
	replace q518_locus_control11 ="0" if q518_locus_control11== "a"
	replace q518_locus_control12 ="0" if q518_locus_control12== "a"
	replace q518_locus_control13="0" if q518_locus_control13== "a"

	destring q518_locus_control1-q518_locus_control13, replace 
	
	egen el_locus_control_raw = rowtotal(q518_locus_control1-q518_locus_control13), m
	
	foreach var of varlist el_locus_control_raw {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}	

	rename norm_el_locus_control_raw el_index_locus_control
	drop el_locus_control_raw*
	
	// perceived stress index	
	** need to flip 2 and 3
	
	foreach var of varlist q519_2_handl_persprob q519_3_thnginyurway {
	gen indi_`var' = `var'
	recode indi_`var' (1=5) (2=4) (4=2) (5=1)
	}
	
	foreach var of varlist q519_1_cntrlimpthngs q519_4_notovercme_diffc {
	gen indi_`var' = `var'
	}
	
	egen raw_stress = rowtotal(indi_*), m
	
	foreach var of varlist raw_stress {
	egen `var'_sd=sd(`var') if treat==0 & `var'!=.
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean=mean(`var') if treat==0 & `var'!=.
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd if `var'!=.
	}	
	
	drop indi_* raw_stress*
	rename norm_raw_stress el_index_stress
	
	// rosenberg self-esteem index
	** index based on sum of scores of all items
	
	foreach var of varlist q520_1satwithmyself q520_3haveno_ofgdqlts q520_4abltodothngd q520_7prsnwrth q520_10_posattitude {
	gen fp_`var'=1 if `var'==4
	replace fp_`var'=2 if `var'==3
	replace fp_`var'=3 if `var'==2
	replace fp_`var'=4 if `var'==1
	}
	
	foreach var of varlist q520_2notgdatall q520_5nthvemuch_proud q520_6feeluseless q520_8wishmre_respct q520_9imfailure {
	gen fp_`var'=`var'
	}
	
	
	foreach var of varlist fp_* {
	egen `var'_sd=sd(`var') if treat==0
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean= mean(`var') if treat==0
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd
	}	

	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_rosenberg=x/y
	drop  fp_q520_1satwithmyself-y
	
	** Table 6-1: Non-cognitive skills (objective measures)
	
	** Delay discounting
	gen indi_q510a = q510a_60rs_30rs

	rename indi_q510a el_index_delay
	
	** Attempted
	gen indi_attempt_a = q427a if q427a != .
	gen indi_attempt_b = q427b if q427a != .
	gen indi_attempt_c = q427c if q427a != .
	gen indi_attempt_d = q427d if q427a != .
	
	gen indi_attempts = indi_attempt_a + indi_attempt_b + indi_attempt_c + indi_attempt_d
	// should I make attempts 0 if they're all missing?
	
	replace indi_attempts = 0 if indi_attempts == . & q501a_gdfrnds != . // replacing with 0 unless the survey is missing totally
	
	gen time_a = 60*q427a_mnts + q427a_scns if indi_attempt_a == 1
	replace time_a = 0 if indi_attempt_a == 0
	gen time_b = 60*q427b_mnts + q427b_scns if indi_attempt_b == 1
	replace time_b = 0 if indi_attempt_b == 0
	gen time_c = 60*q427c_mnts + q427c_scns if indi_attempt_c == 1
	replace time_c = 0 if indi_attempt_c == 0
	gen time_d = 60*q427d_mnts + q427d_scns if indi_attempt_d == 1
	replace time_d = 0 if indi_attempt_d == 0
	
	gen all_time = time_a + time_b + time_c + time_d
	
	rename indi_attempts el_index_attempts
	rename all_time el_index_time
	
	drop indi_attempt* time_*
	
	
	** Scavenger hunt index
	** Create indices from completed and attempted, then create an index from those
	
	forval i = 1/10 {
	gen found_`i' = q521b_outcome_`i' == 1 if q521b_outcome_`i' != . & q521b_outcome_`i' != .
	gen attempt_`i' = q521b_outcome_`i' != 3 if q521b_outcome_`i' != . & q521b_outcome_`i' != .
	}
	
	gen indi_found = found_1 + found_2 + found_3 + found_4 + found_5 + found_6 + found_7 + found_8 + found_9 + attempt_10
	gen indi_attempt = attempt_1 + attempt_2 + attempt_3 + attempt_4 + attempt_5 + attempt_6 + attempt_7 + attempt_8 + attempt_9 + attempt_10
	
	foreach var of varlist indi_found indi_attempt {
	egen `var'_sd=sd(`var') if treat==0
	levelsof `var'_sd, local(x)
	replace `var'_sd=`x'
	egen `var'_mean= mean(`var') if treat==0
	levelsof `var'_mean, local(x)
	replace `var'_mean=`x'
	gen norm_`var'=(`var'-`var'_mean)/`var'_sd
	
	}
	
	egen x=rowtotal(norm_*), missing
	egen y= rownonmiss(norm_*) 
	gen el_index_scavenger=x/y
	drop  found_1 - y
	
	********************* Non-Table 6 tables *********************
	
	** Table 7: child labor

	** adjust for skip patterns
	replace q302_help_lst7dys=0 if q302_help_lst7dys==. & q301_own_farm_gardn==0
	replace q303_paid_lst7dys=0 if q303_paid_lst7dys==. & q302_help_lst7dys==0
	replace q305_spdtime_wkng_nonfrm_busi=0 if q305_spdtime_wkng_nonfrm_busi==. & q304_own_nonfarm_busi==0
	replace q306_rcvincme_lst7dys=0 if q306_rcvincme_lst7dys==. & q305_spdtime_wkng_nonfrm_busi==0
	replace q308_paid_wrk=0 if q308_paid_wrk==. & q307_dnewrk_lst7dys==0

	*rename to be consistent with baseline variable names and baseline coding
		ren q302_help_lst7dys q302_help_farm
		ren q303_paid_lst7dys q303_paid
		ren q305_spdtime_wkng_nonfrm_busi q305_spend_busi
		ren q306_rcvincme_lst7dys q306_income
		ren q308_paid_wrk q308_paid
		ren q401_wrkdne_bfresunrise q401_work_sun
		ren q402_prob_inadqlight q402_prob_light
		ren q403_loudnoise_wrk q403_noises 
		ren q404_wrk_extrmtemp q404_extr_temp
		ren q405_wrk_brickcement q405_brick_indust
		ren q406_wrk_stonebk_crush q406_crushing 
		ren q407_polish_gntestone q407_polishing 
		ren q408_wrk_construction q408_construction 
		ren q409_wrk_carryhvy_load q409_loads
		ren q410_wrk_opertmachine q410_machinery 
		ren q411_wrk_injured q411_injured 
		ren q412_wrk_hndlchemicls q412_toxic 
		ren q414_health_inwrk q414_unwell
		ren q415_wrk_danger q415_hazardous
		ren q416_wrk_whodecids q416_whether
		ren q419_dayoff_ifnotwell q419_able_leave
		ren q420_refdngtask_atwrk q420_able_refuse
		ren q421_leavwrk_ifwanted q421_able_leave
		ren q422a_wrkng_offdebt q422_off_debt
		ren q330_help_grdn_lst12m q330_help_farm 
		ren q331_spendtime_lst12m q331_spend_busi
          

	*Children working outside of family based work in the last 12 months 
	gen work_nonfamily= (q332_wrkdne_lst12m==1 | q307_dnewrk_lst7dys==1 | q418_wrk_wrksite_lst12m == 1)
	replace work_nonfamily=. if (q332_wrkdne_lst12m==. & q307_dnewrk_lst7dys==. & q418_wrk_wrksite_lst12m ==.)
	replace work_nonfamily=. if work_nonfamily==0 & (q332_wrkdne_lst12m==. | q307_dnewrk_lst7dys==. | q418_wrk_wrksite_lst12m ==.)
	label var work_nonfamily "Work involved with non-family members"
	
	*construct hours economic activity;
	destring q311_cal_duration*, replace
	gen hours_worked=0
	forval i= 1/29 {
			replace hours_worked= hours_worked+ q311_cal_duration`i' if (q311_activity`i'>=17) & (q311_activity`i' <=65)	
	}
	forval i = 1/29 {
			replace hours_worked= hours_worked+ q311_cal_duration`i' if inlist(q311_activity`i', 7, 8, 73, 77, 78, 81, 85, 88, 92, 94, 95, 96, 97)
	}
	
	replace hours_worked=hours_worked/60
	replace hours_worked=. if q311_activity1==.
	label var hours_worked "Hours worked in typical day in last week"
	
	*construct hours unpaid household services
	gen hours_unpd_hhser=0
	** Adding in the ones after 2, 3, 4
	forval i= 1/29 {
			replace hours_unpd_hhser= hours_unpd_hhser+ q311_cal_duration`i' if inlist(q311_activity`i', 2, 3, 4, 6, 66, 68, 71, 76, 82, 91, 93)
	}
	replace hours_unpd_hhser=hours_unpd_hhser/60
	label var hours_unpd_hhser "Hours in unpaid households services in a typical day in last week"
	
	replace hours_unpd_hhser=. if q311_activity1==.

	*Hours based inputs into later aggregates
	*5 hours per day corresponding to 20/wk
	*Children economically active for 20 or more hours in the last week
	g ea_gt20= hours_worked>=5
	replace ea_gt20=. if hours_worked==.
	label var ea_gt20 "Hours worked greater than 5 hours in a typical day in last week"

	*Children participating in unpaid household services for 20 or more hours in the last week
	g uhs_gt20= hours_unpd_hhser>=5
	replace uhs_gt20=. if hours_unpd_hhser==.
	label var uhs_gt20 "Hours in unpaid household services greater than 5 hours in a typical day in last week"

	*these are outcome variables used later
	*total hours active
	gen hours_active =hours_worked + hours_unpd_hhser
	label var hours_active "Total Hours Active in Work and Unpaid Household Services"

	**Hours active outside home
	gen hours_outside=0
	*some activities are ambigious as to if they are outside of home
	*we define them as outside the home if the respondent says they did some things outside the home
		*it is not perfect
	forval i= 1/29 {
			replace hours_outside= hours_outside+ (q311_cal_duration`i'*work_nonfamily) if (q311_activity`i'>=18) & (q311_activity`i' <=24)	
			replace hours_outside= hours_outside+ (q311_cal_duration`i'*work_nonfamily) if (inlist(q311_activity`i', 73, 92, 94, 97))

	}
	*these activities are more commonly outside of home
	forval i= 1/29 {
			replace hours_outside= hours_outside+ (q311_cal_duration`i') if (q311_activity`i'>=25) & (q311_activity`i' <=59)	
	}
	
	forval i= 1/29 {
			replace hours_outside= hours_outside+ q311_cal_duration`i' if (inlist(q311_activity`i', 7, 8, 17, 61, 62, 63, 64, 65, 88, 95, 96))
	}

	replace hours_outside=hours_outside/60
	***BF change
	replace hours_outside=. if q311_activity1==.

	*Children in an occupation listed in Appendix One
	*Children participating in any of the processes listed in Appendix Two

	g probact_d=0

		forval i= 1/29 {
				replace probact_d= 1 if inlist(q311_activity`i', 25, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 57, 58, 61, 62, 63, 65)
				}
		replace probact_d=. if q311_activity1==.
		label var probact_d "Child participated in a prohibited occupation or process in a typical day in last week"
		
	g probact_7= inlist(q310_type_work, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 30, 41, 42, 45, 46, 47, 49)
		replace probact_7=. if q307_dnewrk_lst7dys==. & q302_help_farm==. & q305_spend_busi==.
		replace probact_7=0 if q307_dnewrk_lst7dys==0 & q302_help_farm==0 & q305_spend_busi==0 & probact_7~=1
		label var probact_7 "Child participated in a prohibited occuption or process in the last 7 days"
		
	g probact= probact_7==1 | probact_d==1
	replace probact=. if probact_7==. & probact_d==.
	replace probact=. if probact==0 &  (probact_7==. | probact_d==.)
		label var probact "Child pariticpated in prohibited occupation or process in last 7 days or in typical day"
	

		
	*Children working in an economic activity in the last 12 months that is hazardous by its nature or circumstance (based on self-reported job characteristics). 
	g hazcirc=0

	#delimit;

	foreach x in 
	q401_work_sun q402_prob_light q403_noises q404_extr_temp q405_brick_indust q406_crushing q407_polishing 
	q408_construction q409_loads q410_machinery q411_injured q412_toxic q414_unwell q415_hazardous {;
	di "`x'"; d `x'; summ `x';
		replace hazcirc= 1 if `x'==1; 
	};
	
	foreach x in 
	q415_hazardous {;
		replace hazcirc= . if `x'==. & hazcirc==0; 
	};

	replace hazcirc=0 if hazcirc==. & (q330_help_farm==0 & q331_spend_busi==0 & q332_wrkdne_lst12m==0 );

	label var hazcirc "Working under self-reported hazardous circumstances";
	
	#delimit cr

	label var hazcirc "Child participated in hazardous work in last 12 months based on circumstances of work"

	*Child (potentially) in forced labor (reports being forced to work and unable to leave)
	g pfl=0

	replace pfl= 1 if  (q419_able_leave==0 | q420_able_refuse==0 | q421_able_leave==0 |  inlist(q416_whether, 3, 4, 5, 6,7))
	foreach x in q419_able_leave q420_able_refuse q421_able_leave  {
	replace pfl=. if pfl==0 & `x'==.
	}

	replace pfl=0 if pfl==.  & (q330_help_farm==0 & q331_spend_busi==0 & q332_wrkdne_lst12m==0 )
	label var pfl "Potentially in forced labor, unable to refuse work"


	*Children (potentially) in debt bondage (reports working for a debt and being unable to leave)
	replace q422_off_debt=0 if q422_off_debt==. & q421_able_leave==1
	replace q422_off_debt=1 if q416_whether==5

	g pdb=pfl * q422_off_debt
	replace pdb=0 if pdb==. & (q330_help_farm==0 & q331_spend_busi==0 & q332_wrkdne_lst12m==0 )

	label var pdb "Potentially in Debt-Bondage, unable to refuse work and working off debt"

	replace pfl=0 if q330_help_farm==0 & q331_spend_busi==0 & q332_wrkdne_lst12m==0 
	replace pdb=0 if q330_help_farm==0 & q331_spend_busi==0 & q332_wrkdne_lst12m==0 
	
	*Aggregates
	*Children Engaged in Other Worst Forms of Child Labor
	gen otherworst_labor= pfl==1 | pdb==1
	replace otherworst_labor=. if pfl==. & pdb==.
	replace otherworst_labor=. if (pfl==. | pdb==.) & otherworst_labor==0
	label var otherworst_labor "Engaged in Other Worst Forms of Child Labor"

	*Children Engaged in Hazardous Child Labor
	g hazardous_labor = hazcirc==1 | probact==1
	replace hazardous_labor=. if hazcirc==. & probact==.
	replace hazardous_labor=. if hazardous_labor==0 & (hazcirc==. | probact==.)
	label var hazardous_labor "Engaged in Hazardous Child Labor"

	*Child labor
	g child_labor = hazardous_labor==1 | otherworst_labor==1 | ea_gt20==1 | uhs_gt20==1 | work_nonfamily==1
	replace child_labor =. if hazardous_labor==. & otherworst_labor==. & ea_gt20==. & uhs_gt20==. & work_nonfamily==.
	replace child_labor =. if child_labor==0 & (hazardous_labor==. | otherworst_labor==. | ea_gt20==. | uhs_gt20==. | work_nonfamily==.)
	label var child_labor "Engaged in Child Labor"

	*Working Child
	gen work_child=(q330_help_farm==1|q331_spend_busi==1| q332_wrkdne_lst12m==1 | q302_help_farm==1 | q305_spend_busi ==1 | q307_dnewrk_lst7dys == 1 | child_labor==1)
	replace work_child=. if (q330_help_farm==. & q331_spend_busi==. & q332_wrkdne_lst12m==. & q302_help_farm ==. & q305_spend_busi == . & q307_dnewrk_lst7dys == . & child_labor==.)
	replace work_child=. if work_child==0 & (q330_help_farm==. | q331_spend_busi==. | q332_wrkdne_lst12m==. | q302_help_farm ==. | q305_spend_busi == . | q307_dnewrk_lst7dys == . | child_labor==.)
	label var work_child "Child is Economically Active or in Child Labor"


	**Working for pay
	** Leave out 424f--"Nothing"
																																																			
	gen work_pay=	(q424a_cash==1 | q424b_newskill==1 | q424c_education==1 | q424d_shelter_foodcloths==1 | q424e_medicalsupp==1 | q424g_toys==1 | q424h_fruits_veg == 1 | q424i_chocolate == 1 | q424j_dryfruit == 1 | q424k_bangles == 1 | q424l_jewellery == 1 | q424m_breakfast == 1 | q424n_utensils == 1 | q424o_snacks == 1 | q303_paid==1 | q306_income==1 | q308_paid==1)
		replace work_pay=. if work_child==.
		label var work_pay "Works for Pay"

		
	foreach x in work_child work_pay work_nonfamily hours_worked hours_unpd_hhser hours_active hours_outside hazardous_labor otherworst_labor child_labor ea_gt20 uhs_gt20 probact hazcirc pdb pfl {
	summ `x'
	ren `x' el_`x'
	}
		
					
	** Table 8: cognitive skills and academic achievement ***************************

	** Hours studying at home
		** Minutes spent on schoolwork based on Q311
		
	gen el_time_homework = 0 if q311_activity1 != .
	forval i= 1/29 {
	replace el_time_homework =  el_time_homework + q311_cal_duration`i' if inlist(q311_activity`i', 14, 15)	
	}
	replace el_time_homework = el_time_homework/60
	// activities are tuitions outside home and studying at home / tuitions at home
	
	** Total hours spent on school
	
	gen el_time_school = 0 if q311_activity1 !=.
	forval i= 1/29 {
	replace el_time_school =  el_time_school + q311_cal_duration`i' if inlist(q311_activity`i', 9, 10 , 14, 15)	
	}
	replace el_time_school = el_time_school/60
		** Studying, time in school, time traveling to/from school based on Q311
	
	** ASER score - Math
		** Score on the test

	** 0 is no proficiency, 1 is single digit recognition, 2 double digit recognition, 3 subtraction, 4 division
	
	gen el_mathproficiency=.
	
	replace el_mathproficiency=4 if (a1sub==0) & a4==0
	replace el_mathproficiency=3 if (a1sub==0) & (a4==1 | a4==2)
	replace el_mathproficiency=2 if (a1sub==1 | a1sub==2) & a2==0
	replace el_mathproficiency=1 if (a1sub==1 | a1sub==2) & (a2==1 | a2==2) & (a3==0)
	replace el_mathproficiency=0 if (a1sub==1 | a1sub==2) & (a2==1 | a2==2) & (a3==1 | a3==2)
			
	** ASER score - Hindi
		** Score on the test
	
	gen el_hindiproficiency=.
	*0 is no reading, 1 is word, 2 is words, 3 is paragraph, 4 is story
	
	replace el_hindiproficiency=4 if (b1==0) & b4==0
	replace el_hindiproficiency=3 if (b1==0) & (b4==1 | b4==2)
	replace el_hindiproficiency=2 if (b1==1 | b1==2) & b2==0
	replace el_hindiproficiency=1 if (b1==1 | b1==2) & (b2==1 | b2==2) & (b3==0)
	replace el_hindiproficiency=0 if (b1==1 | b1==2) & (b2==1 | b2==2) & (b3==1 | b3==2)
			
	** ASER score - English
		** Score on the test
	
	gen el_englishproficiency=.
	*0 is no reading, 1 is capital letters, 2 is lowercase letters, 3 is words, 4 is sentences
		
	replace el_englishproficiency=0 if (c1_5capletters==1 | c1_5capletters==2) 
	replace el_englishproficiency=1 if (c1_5capletters==0) & (c2_5small==1 | c2_5small==2)
	replace el_englishproficiency=2 if (c2_5small==0) & (c3_5words==1 | c3_5words==2)
	replace el_englishproficiency=3 if (c3_5words==0) & (c4_read==1 | c4_read==2)
	replace el_englishproficiency=4 if (c4_read==0)
	
		
	** Table 5 : school progression / completion

	** School dropout
		** 1 if HH Q214 is "no" or if child survey Q203 is "no" 
		gen el_index_dropout = 1 if a212_attd_schl_collge_ == 0 | q203b_attndschl_apr18 == 0 
		replace el_index_dropout = 0 if a212_attd_schl_collge_ != 0 & q203b_attndschl_apr18 !=0
		
		replace el_index_dropout = . if a212_attd_schl_collge_ == . & q203b_attndschl_apr18 == .
		// if they're both misisng, should be missing
	
	
	** 1 if girl is enrolled at or above grave seven based on household survey Q215
	** 0 if not enrolled in school or not advanced to class 7
	gen el_index_grade = q204_recattnd_class >=7
	replace el_index_grade=. if q204_recattnd_class==.
	replace el_index_grade=0 if el_index_grade==. & q203b_attndschl_apr18==0
	replace el_index_grade=0 if el_index_dropout==1

	** School attendance
	gen attend= q205_goto_schl/q206_schlopen_dys
	replace attend = . if el_index_dropout==1

	gen dum_attend= attend>0
	replace dum_attend=. if attend==.

	foreach var of varlist el_index_grade attend dum_attend {
	replace `var'=. if mis_el_ch_survey==1 
	}

	rename attend el_school_attend
	rename dum_attend el_school_dummy
	
	tempfile use endline_indices
	save `endline_indices'
	
	
	** Generate endline mother's education

	use "$data/ehsection2.dta", clear
	 
	ren a207_complete_edu_ momed
	keep hh_id mem momed
	sort hh_id mem
	tempfile mom
	save `mom', replace
	 
	use "`endline_indices'", clear
	drop mem
	ren a402_who_she_ mem
	ren a406_high_edu_  momed2
	sort hh_id mem
	
	** need education for mothers that are both in the household & living elsewhere
	merge m:1 hh_id mem using "`mom'" // merge in mom data
	drop if _merge==2
	 
	label list a207 
	label list  a406
	 
	tab momed 
	tab momed2
	
	replace momed=. if momed==.d
	replace momed=. if momed==.n 
	replace momed2=. if momed2==.d
	replace momed2=. if momed2==.n 
	 
	** Mother has no formal schooling 
	g momnoschool= momed==1 | momed2==1 | momed2==2
	replace momnoschool=. if momed==. & momed2==.
	
	** Mother's education is past primary
	g mompostprim= (momed>=5 & momed<18) | (momed2>=4 & momed2<=10)
	replace mompostprim=. if momed==. & momed2==.
	 
	summ momnoschool mompostprim
		
	keep el_* dise treat child_id hh_id strata* mis_* momnoschool mompostprim
				
	save "$merged_data/endline_indices.dta",replace
	
	
		

		
