** Q statistics for Replication Table 6

	** Load endline indxes
	use "$merged_data/endline_indices.dta", clear
	
	** Merge in baseline indexes
	merge 1:1 child_id using "$merged_data/bl_indices.dta"
	
	tab _merge if mis_el == 1
	** Correclty identified the girls not in the endline survey
	
	drop if _merge == 2 
	drop _merge

	** Lists of controls
	global nocontrols treat stratafixed*, cl(dise) 
	global basiccontrols treat stratafixed* employ1-employ6 mis_employ1-mis_employ6 age2-age11 mis_age2- mis_age11, cl(dise)

	global table6 el_index_delay el_index_attempts el_index_time el_index_scavenger el_index_marriage-el_index_enumerator el_index_p_strengths-el_index_p_marriage
	global table6_el_only el_index_locus_control el_index_stress el_index_rosenberg
	
	global additionalcontrols el_index_socioemotional_bl el_index_socioemotional_mis_bl el_index_movement1_mis_bl el_index_empowerment_bl el_index_empowerment_mis_bl el_index_selfesteem_bl el_index_selfesteem_mis_bl el_index_planning_bl el_index_planning_mis_bl el_index_marr_expect_bl el_index_marr_expect_mis_bl el_index_employ_bl el_index_employ_mis_bl el_index_gender_bl el_index_gender_mis_bl el_index_cantrill_bl el_index_cantrill_mis_bl el_index_enumerator_bl el_index_enumerator_mis_bl 
	
	** Rename baseline & missing baseline so that I can use the loop from the endline indices
	rename bl_index_delay el_index_delay_bl
	rename bl_index_attempts el_index_attempts_bl
	rename bl_index_time el_index_time_bl
	rename bl_index_scavenger el_index_scavenger_bl
	rename bl_index_marriage el_index_marriage_bl
	rename bl_index_socioemotional el_index_socioemotional_bl
	rename bl_index_movement1 el_index_movement1_bl
	rename bl_index_empowerment el_index_empowerment_bl
	rename bl_index_selfesteem el_index_selfesteem_bl
	rename bl_index_planning el_index_planning_bl
	rename bl_index_marr_expect el_index_marr_expect_bl
	rename bl_index_employ el_index_employ_bl
	rename bl_index_gender el_index_gender_bl
	rename bl_index_cantrill el_index_cantrill_bl
	rename bl_index_enumerator el_index_enumerator_bl
	rename bl_index_p_strengths el_index_p_strengths_bl
	rename bl_index_p_efficacy el_index_p_efficacy_bl
	rename bl_index_p_movement1 el_index_p_movement1_bl
	rename bl_index_p_communication el_index_p_communication_bl
	rename bl_index_p_gender el_index_p_gender_bl
	rename bl_index_p_schooling el_index_p_schooling_bl
	rename bl_index_p_marriage el_index_p_marriage_bl
	
	rename mis_bl_index_delay el_index_delay_mis_bl
	rename mis_bl_index_attempts el_index_attempts_mis_bl
	rename mis_bl_index_time el_index_time_mis_bl
	rename mis_bl_index_scavenger el_index_scavenger_mis_bl
	rename mis_bl_index_marriage el_index_marriage_mis_bl
	rename mis_bl_index_socioemotional el_index_socioemotional_mis_bl
	rename mis_bl_index_movement1 el_index_movement1_mis_bl
	rename mis_bl_index_empowerment el_index_empowerment_mis_bl
	rename mis_bl_index_selfesteem el_index_selfesteem_mis_bl
	rename mis_bl_index_planning el_index_planning_mis_bl
	rename mis_bl_index_marr_expect el_index_marr_expect_mis_bl
	rename mis_bl_index_employ el_index_employ_mis_bl
	rename mis_bl_index_gender el_index_gender_mis_bl
	rename mis_bl_index_cantrill el_index_cantrill_mis_bl
	rename mis_bl_index_enumerator el_index_enumerator_mis_bl
	rename mis_bl_index_p_strengths el_index_p_strengths_mis_bl
	rename mis_bl_index_p_efficacy el_index_p_efficacy_mis_bl
	rename mis_bl_index_p_movement1 el_index_p_movement1_mis_bl
	rename mis_bl_index_p_communication el_index_p_communication_mis_bl
	rename mis_bl_index_p_gender el_index_p_gender_mis_bl
	rename mis_bl_index_p_schooling el_index_p_schooling_mis_bl
	rename mis_bl_index_p_marriage el_index_p_marriage_mis_bl
	
	
	** For objective measures 
	global asercontrols bl_index_dropout mis_bl_index_dropout bl_index_grade mis_bl_index_grade bl_school_attend mis_bl_school_attend bl_time_homework bl_time_school mis_bl_time_homework mis_bl_time_school
	** For Panel C
	global imbalancecontrols treat stratafixed* bl_obc mis_bl_obc bl_work_child mis_bl_work_child bl_hours_outside mis_bl_hours_outside
		
	
	***********************************Table 6 Q-statistics, Panel A***********************************
		** Panel A: Q stats	
		tempfile table6_vars
		save `table6_vars'
	
			local line=1
		local sel=`line'+1
		g Xvar=" "
		g Xorder=.
		g Xcon=.
		g Xb=.
		g Xperc=.
		g Xp=.
	
				
	foreach var of varlist $table6 $table6_el_only {
		reg `var' $nocontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}
	
	keep Xvar-Xp
	drop if Xb==.
	
	*** CALCULATING P-VALUES & OUTPUT ***
		
	** Ending, from EE
	
	#delimit ;
	
	//keep Xvar-Xp;

	preserve;
		
	*compute significance based on fixed fdr;
	keep Xorder Xp;
	drop if Xp==.;
	local fdr=0.25;
	sort Xp;
	g order=_n;
	count;
	local num=r(N);
	g cBH=(order/`num')*`fdr';
	g value=" ";
	replace value="*" if Xp<cBH & Xp<0.05;
	
	*compute q-value;

	local qval = 1;

	* Generate the variable that will contain the BH (1995) q-values;

	gen bh95_qval = `qval' ;

	/* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  
	The loop ends by checking which hypotheses are rejected at q = 0.001.*/;
qui {;
	while `qval' > 0 {;
		* Generate value qr/M;
		quietly gen fdr_temp = `qval'*order/`num';
		* Generate binary variable checking condition p(r) <= qr/M;
		quietly gen reject_temp = (fdr_temp>=Xp) if fdr_temp~=.;
		* Generate variable containing p-value ranks for all p-values that meet above condition;
		quietly gen reject_rank = reject_temp*order;
		* Record the rank of the largest p-value that meets above condition;
		quietly egen total_rejected = max(reject_rank);
		* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition;
		replace bh95_qval = `qval' if order <= total_rejected & order~=.;
		* Reduce q by 0.001 and repeat loop;
		quietly drop fdr_temp reject_temp reject_rank total_rejected;
		local qval = `qval' - .001;
	};
		
	};
	
	
	keep Xorder value bh95_qval;
	sort Xorder;
	tempfile FDR;
	save `FDR';
	restore;
	
	g mark=1 if Xorder~=.;
	replace mark=2 if Xorder==.;
	
	g XN=Xorder[_n-1];
	replace Xorder=XN if Xorder==.;
	drop XN;
	
	merge m:1 Xorder using `FDR';
	
	*These regressions have errors;
	list Xvar if _merge==1;
	
	*Get ready to export to excel;
	
	*first clean up the regression output;
	tostring Xcon Xb Xp bh95_qval, replace force format(%9.3f);
	replace Xperc=Xperc*100; tostring Xperc, replace force format(%9.1f);

	sort Xorder mark;
	
	*Parenthesis around standard errors;
	g o="("; g c=")"; replace Xcon=o+Xcon+c if Xvar==" "; replace Xb=o+Xb+c if Xvar==" "; drop o c;

	foreach var of varlist value bh95_qval Xp Xperc {;
	replace `var'=" " if mark==2;
	};
	
	label var Xvar "Variable"; 
	label var Xcon "Control Mean / (SE)";
	label var Xb "Treatment Mean / (SE)";
	label var value "P<0.05 & FDR<0.25";
	label var Xp "P-value";
	label var bh95_qval "Q-Statistic";
	label var Xperc "Percentage Change";
	
	keep Xvar Xcon Xb value  Xp bh95_qval Xperc;
	order Xvar Xcon Xb value Xp bh95_qval Xperc;
	
	export excel "$tables/table6/Table6_A_Q.xls", replace  firstrow(varlabels) ;
		
	#delimit cr
	
	
	***********************************Table 6 Q-statistics, Panel B ***********************************
		** Panel B: Q stats	

		use `table6_vars', clear
	
		local line=1
		local sel=`line'+1
		g Xvar=" "
		g Xorder=.
		g Xcon=.
		g Xb=.
		g Xperc=.
		g Xp=.
	
				
	foreach var of varlist $table6  {
	
		reg `var' `var'_bl `var'_mis_bl $basiccontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}
	
	** Endline only measures have different controls
	
	foreach var of varlist $table6_el_only {
		
		reg `var' $additionalcontrols  $basiccontrols 
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}
	
	
	keep Xvar-Xp
	drop if Xb==.
	
	*** CALCULATING P-VALUES & OUTPUT ***
		
	** Ending, from EE
	
	#delimit ;
	
	//keep Xvar-Xp;

	preserve;
		
	*compute significance based on fixed fdr;
	keep Xorder Xp;
	drop if Xp==.;
	local fdr=0.25;
	sort Xp;
	g order=_n;
	count;
	local num=r(N);
	g cBH=(order/`num')*`fdr';
	g value=" ";
	replace value="*" if Xp<cBH & Xp<0.05;
	
	*compute q-value;

	local qval = 1;

	* Generate the variable that will contain the BH (1995) q-values;

	gen bh95_qval = `qval' ;

	/* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  
	The loop ends by checking which hypotheses are rejected at q = 0.001.*/;
qui {;
	while `qval' > 0 {;
		* Generate value qr/M;
		quietly gen fdr_temp = `qval'*order/`num';
		* Generate binary variable checking condition p(r) <= qr/M;
		quietly gen reject_temp = (fdr_temp>=Xp) if fdr_temp~=.;
		* Generate variable containing p-value ranks for all p-values that meet above condition;
		quietly gen reject_rank = reject_temp*order;
		* Record the rank of the largest p-value that meets above condition;
		quietly egen total_rejected = max(reject_rank);
		* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition;
		replace bh95_qval = `qval' if order <= total_rejected & order~=.;
		* Reduce q by 0.001 and repeat loop;
		quietly drop fdr_temp reject_temp reject_rank total_rejected;
		local qval = `qval' - .001;
	};
		
	};
	
	
	keep Xorder value bh95_qval;
	sort Xorder;
	tempfile FDR;
	save `FDR';
	restore;
	
	g mark=1 if Xorder~=.;
	replace mark=2 if Xorder==.;
	
	g XN=Xorder[_n-1];
	replace Xorder=XN if Xorder==.;
	drop XN;
	
	merge m:1 Xorder using `FDR';
	
	*These regressions have errors;
	list Xvar if _merge==1;
	
	*Get ready to export to excel;
	
	*first clean up the regression output;
	tostring Xcon Xb Xp bh95_qval, replace force format(%9.3f);
	replace Xperc=Xperc*100; tostring Xperc, replace force format(%9.1f);

	sort Xorder mark;
	
	*Parenthesis around standard errors;
	g o="("; g c=")"; replace Xcon=o+Xcon+c if Xvar==" "; replace Xb=o+Xb+c if Xvar==" "; drop o c;

	foreach var of varlist value bh95_qval Xp Xperc {;
	replace `var'=" " if mark==2;
	};
	
	label var Xvar "Variable"; 
	label var Xcon "Control Mean / (SE)";
	label var Xb "Treatment Mean / (SE)";
	label var value "P<0.05 & FDR<0.25";
	label var Xp "P-value";
	label var bh95_qval "Q-Statistic";
	label var Xperc "Percentage Change";
	
	keep Xvar Xcon Xb value  Xp bh95_qval Xperc;
	order Xvar Xcon Xb value Xp bh95_qval Xperc;
	
	export excel "$tables/table6/Table6_B_Q.xls", replace  firstrow(varlabels) ;
		
	#delimit cr

	
	***********************************Table 6 Q-statistics, Panel B ***********************************
		** Panel B: Q stats	

		use `table6_vars', clear
	
		local line=1
		local sel=`line'+1
		g Xvar=" "
		g Xorder=.
		g Xcon=.
		g Xb=.
		g Xperc=.
		g Xp=.
				
	foreach var of varlist $table6  {
	
		reg `var' $imbalancecontrols  `var'_bl `var'_mis_bl $basiccontrols
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}
	
	** Endline only measures have different controls
	
	foreach var of varlist $table6_el_only {
		
		reg `var' $imbalancecontrols  $additionalcontrols  $basiccontrols  
	
		replace Xvar="`var'" in `line'
		replace Xorder=`line' in `line'
		replace Xb=_b[treat] in `line'
		replace Xb=_se[treat] in `sel'
		replace Xp=(2 * ttail(e(df_r), abs(_b[treat]/_se[treat]))) in `line'

	reg `var' treat, cl(dise)
	
		replace Xcon=_b[_cons] in `line'
		replace Xcon=_se[_cons] in `sel'
		replace Xperc=Xb/Xcon in `line'
		local line=`line'+2
		local sel=`line'+1
	}

	
	keep Xvar-Xp
	drop if Xb==.
	
	*** CALCULATING P-VALUES & OUTPUT ***
		
	** Ending, from EE
	
	#delimit ;
	
	//keep Xvar-Xp;

	preserve;
		
	*compute significance based on fixed fdr;
	keep Xorder Xp;
	drop if Xp==.;
	local fdr=0.25;
	sort Xp;
	g order=_n;
	count;
	local num=r(N);
	g cBH=(order/`num')*`fdr';
	g value=" ";
	replace value="*" if Xp<cBH & Xp<0.05;
	
	*compute q-value;

	local qval = 1;

	* Generate the variable that will contain the BH (1995) q-values;

	gen bh95_qval = `qval' ;

	/* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  
	The loop ends by checking which hypotheses are rejected at q = 0.001.*/;
qui {;
	while `qval' > 0 {;
		* Generate value qr/M;
		quietly gen fdr_temp = `qval'*order/`num';
		* Generate binary variable checking condition p(r) <= qr/M;
		quietly gen reject_temp = (fdr_temp>=Xp) if fdr_temp~=.;
		* Generate variable containing p-value ranks for all p-values that meet above condition;
		quietly gen reject_rank = reject_temp*order;
		* Record the rank of the largest p-value that meets above condition;
		quietly egen total_rejected = max(reject_rank);
		* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition;
		replace bh95_qval = `qval' if order <= total_rejected & order~=.;
		* Reduce q by 0.001 and repeat loop;
		quietly drop fdr_temp reject_temp reject_rank total_rejected;
		local qval = `qval' - .001;
	};
		
	};
	
	
	keep Xorder value bh95_qval;
	sort Xorder;
	tempfile FDR;
	save `FDR';
	restore;
	
	g mark=1 if Xorder~=.;
	replace mark=2 if Xorder==.;
	
	g XN=Xorder[_n-1];
	replace Xorder=XN if Xorder==.;
	drop XN;
	
	merge m:1 Xorder using `FDR';
	
	*These regressions have errors;
	list Xvar if _merge==1;
	
	*Get ready to export to excel;
	
	*first clean up the regression output;
	tostring Xcon Xb Xp bh95_qval, replace force format(%9.3f);
	replace Xperc=Xperc*100; tostring Xperc, replace force format(%9.1f);

	sort Xorder mark;
	
	*Parenthesis around standard errors;
	g o="("; g c=")"; replace Xcon=o+Xcon+c if Xvar==" "; replace Xb=o+Xb+c if Xvar==" "; drop o c;

	foreach var of varlist value bh95_qval Xp Xperc {;
	replace `var'=" " if mark==2;
	};
	
	label var Xvar "Variable"; 
	label var Xcon "Control Mean / (SE)";
	label var Xb "Treatment Mean / (SE)";
	label var value "P<0.05 & FDR<0.25";
	label var Xp "P-value";
	label var bh95_qval "Q-Statistic";
	label var Xperc "Percentage Change";
	
	keep Xvar Xcon Xb value  Xp bh95_qval Xperc;
	order Xvar Xcon Xb value Xp bh95_qval Xperc;
	
	export excel "$tables/table6/Table6_C_Q.xls", replace  firstrow(varlabels) ;
		
	#delimit cr


