** Balance table for households

* Table 1: summary statistics

	use "$merged_data/bhc_combined.dta",clear
	
	** Check that households with multiple girls show up multiple times

	duplicates tag hh_id, gen(multiple) // matches "girls" variable: have the right doubling of households
	tab multiple
	drop multiple
	
* Table 1: summary statistics	
	
	** 
	tab q106_own_land_bighas, m
	// note that percentages in table are from sample size with new_el dropped
	tab q107_culti_bighas, m
	// note that percentages in table are from sample size with new_el dropped
	
	gen bl_backward = (q103_social_grp == 3) if mis_bl_hh_survey != 1 & new_el != 1  
	gen bl_employ_wage_salary = (q104_employment == 3) if mis_bl_hh_survey != 1 & new_el!=1 
	gen bl_employ_self_agr = (q104_employment == 1) if mis_bl_hh_survey != 1 & new_el!=1 
	gen bl_employ_self_othr = (q104_employment == 2) if mis_bl_hh_survey != 1 & new_el!=1 
	gen bl_employ_labor_agr = (q104_employment == 4) if mis_bl_hh_survey != 1 & new_el!=1 
	gen bl_employ_labor_othr = (q104_employment == 5) if mis_bl_hh_survey != 1 & new_el!=1 
	
	** Counting consumption expenditure over the last 30 days for non-food items
	egen bl_non_food_30=rowtotal(  q512_pan- q522_medicine) if mis_bl_hh_survey != 1 & new_el != 1  
	
	destring  q501_cereals- q536_repair, replace
	egen bl_food_30=rowtotal( q501_cereals- q511_tea) if mis_bl_hh_survey != 1 & new_el != 1

	** Consumption expenditure on durable goods for the last 365 days
	egen bl_durbl_365=rowtotal(  q528_furniture- q536_repair) if mis_bl_hh_survey != 1 & new_el != 1 
	
	gen bl_mother_edu = 1 if q213_edu>= 4 & q213_edu != . & q213_edu !=.d
	// 1 is primary or higher

	gen bl_economicshock = q113a==1 | q113b==1 | q113c==1 if mis_bl_hh_survey != 1 & new_el != 1     
	gen bl_deathillshock = q113d==1 | q113e==1 | q113f==1  if mis_bl_hh_survey != 1 & new_el != 1 	
	gen bl_crimedisputeshock = q113h==1 | q113i==1 | q113j==1 if mis_bl_hh_survey != 1 & new_el != 1  
	
	global table1 bl_backward bl_employ* bl_non_food_30 bl_food_30 bl_durbl_365 q106_own_land_bighas q107_culti_bighas q108_mgnreg_card bl_economicshock bl_crimedisputeshock bl_deathillshock

	keep hh_id child_id treat dise mis_bl_hh mis_bl_ch new_el mis_el  $table1
	
	tempfile table1
	save `table1'
	
	** calculating things for household members
	
	use "$data/bhsection2.dta",clear
	gen target_girl = child_id !=.
	
	gen boy_under18 = (q203_age < 18 & q204_gender == 1) 
	gen girl_under18 = (q203_age < 18 & q204_gender == 0) 
	
	collapse (count) mem (sum) target_girl (sum) boy_under18 (sum) girl_under18, by(hh_id)
	
	merge 1:m hh_id using "`table1'"
	
	drop _merge
	
	order target_girl mem boy_under18 girl_under18 $table1
	
	tempfile balance
	save `balance'
	
	************************************* Create tables *************************************
	
	** Table 1
	
	use "`balance'", clear	
	
	tabstat target_girl-bl_deathillshock,statistics(mean sd n) columns(statistics) varwidth(24) format(%8.3f) save

	mat T = r(StatTotal)' 

	putexcel set "$tables/summary/Table1.xlsx",replace 
	putexcel A1 = matrix(T), names
	
	** table 3: balance table
	
	** Control girls
	preserve
	keep if treat == 0
	
	tabstat target_girl-bl_deathillshock,statistics(mean sd n) columns(statistics) varwidth(24) format(%8.3f) save

	mat T = r(StatTotal)' 

	putexcel set "$tables/summary/Table3_control.xlsx",replace 
	putexcel A1 = matrix(T), names
	
	restore
	preserve
	
	** Treated girls
	keep if treat == 1
	
	tabstat target_girl-bl_deathillshock,statistics(mean sd n) columns(statistics) varwidth(24) format(%8.3f) save

	mat T = r(StatTotal)' 

	putexcel set "$tables/summary/Table3_treat.xlsx",replace 
	putexcel A1 = matrix(T), names
	
	restore
	
	** Difference
	reg target_girl treat, cl(dise)
	outreg2  using "$tables/summary/Table3_dif.xls", replace dec(3) excel
	
	foreach var of varlist mem-bl_deathillshock {
	
	reg `var' treat ,cl(dise)
	outreg2 using "$tables/summary/Table3_dif.xls", dec(3) excel
	}
	
	
